### Name: convexLSE
### Title: Compute the nonparamateric LSE of a convex hazard
### Aliases: convexLSE
### Keywords: nonparametric survival iteration optimize

### ** Examples

# Generate sample data:
set.seed(1111, kind="default")
x       <- rweibull(50, 3) 

# Set the value of TT:
TT      <- 1

# Find the lse  
lse     <- convexLSE(x, TT=TT)

# And the lse has minimum at
lse$antimode

# Check the bisection algorithm
diag    <- read.table("convexLSE.out", header=TRUE)
diag

plot(diag$antimode, diag$phi, pch=16, col="blue", cex=1, main="diagnostics", ylab="phi", xlab="antimode")

# plot the true hazard function and the lse
h.true  <- function(x) 3*x^2
tt      <- c(0,sort(lse$lse$supp$tau), sort(lse$lse$supp$eta), TT)
yy      <- sapply(tt, h, supp=lse$lse$supp, hpar=lse$lse$mix)

plot(h.true, xlim=c(0,TT), lwd=2, col="blue", ylab="hazard", xlab="time", main="LSE of convex hazard")
lines(tt,yy, lwd=2, col="red")
legend("topleft", c("true","estimated"),col=c("blue", "red"), lwd=2, inset = .05)



