### Name: convexMLE
### Title: Compute the nonparametric MLE of a convex hazard
### Aliases: convexMLE
### Keywords: nonparametric survival iteration optimize

### ** Examples

# Generate sample data:
set.seed(1111, kind="default")
x       <- rbeta(100, 0.5, 0.5) 

# Find the mle (this takes a few minutes)       
mle     <- convexMLE(x, M=1000)

# And the mle has minimum at
mle$antimode

# Check the bisection algorithm
diag    <- read.table("convexMLE.out", header=TRUE)
diag

plot(diag$antimode, diag$negllh, pch=16, col="blue", main="diagnostics", ylab="phi", xlab="antimode")

# plot the true hazard function and the lse
h.true  <- function(x) dbeta(x, 0.5, 0.5)/(1-pbeta(x, 0.5, 0.5))
tt      <- c(0,sort(mle$mle$supp$tau), sort(mle$mle$supp$eta), max(x))
yy      <- sapply(tt, h, supp=mle$mle$supp, hpar=mle$mle$mix)

plot(h.true, xlim=c(0, 0.95), lwd=2, col="blue", ylab="hazard", xlab="time", main="MLE of convex hazard")
lines(tt,yy, lwd=2, col="red")
legend("topleft", c("true","estimated"),col=c("blue", "red"), lwd=2, inset = .05)





