### Name: hazard
### Title: Create a hazard function (and its integral) given its support
###   and mixing measure.
### Aliases: hazard H h
### Keywords: survival nonparametric

### ** Examples

# Generate sample data:
set.seed(1111, kind="default")
x       <- rweibull(50, 3) 

# Find the LSE with antimode a=0 over the range [0,1]:
TT      <- 1
lse     <- srLSE(x, a=0, TT=TT)

# create simpler function to evaluate hazard and cumulative hazard
h.lse   <- function(t){ return(h(t, lse$lse$supp, lse$lse$mix))}
H.lse   <- function(t){ return(H(t, lse$lse$supp, lse$lse$mix))}

# hazard function at t=0
h.lse(0)

# cumulative hazard function at t=1
H.lse(1)

# plot the hazard function h.lse
tt      <- c(0,sort(lse$lse$supp$tau), sort(lse$lse$supp$eta), TT)      # where h.lse changes slope
yy      <- sapply(tt, h.lse)                                            # values of h.lse at tt
plot(tt, yy, xlim=c(0,TT), type="l", lwd=2, col="red", ylab="hazard", xlab="time", main="LSE (a=0)")



