### Name: srMLE
### Title: Compute the MLE of a convex hazard with fixed antimode
### Aliases: srMLE
### Keywords: nonparametric survival iteration optimize

### ** Examples

# Generate sample data:
set.seed(3333, kind="default")
x       <- rweibull(50, 3) 

# Find the LSE with antimode a=0 over the range [0,1]:
TT      <- 1    
mle     <- srMLE(x, a=0)

# plot the true hazard function and the lse
h.true  <- function(x) 3*x^2
tt      <- c(0,sort(mle$mle$supp$tau), sort(mle$mle$supp$eta), max(x))
yy      <- sapply(tt, h, supp=mle$mle$supp, hpar=mle$mle$mix)

plot(h.true, xlim=c(0,max(x)), lwd=2, col="blue", ylab="hazard", xlab="time", main="MLE (a=0)")
lines(tt,yy, lwd=2, col="red")
legend("topleft", c("true","estimated"),col=c("blue", "red"), lwd=2, inset = .05)



